* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [SaaS Discovery](https://help.sap.com/docs/leanix/ea/saas-discovery)
  * Microsoft Defender for Cloud Apps (MDCA) Integratio…
